@@ -86,9 +86,7 @@ def _create_config_class_instance(
         if instance is HAS_DEFAULT_VALUE:
             continue
 
-        add_contains_getattribute_getitem_get_methods_to(
-            field.type, sections[field.name] if field.name in sections else {}
-        )
+        add_contains_getattribute_getitem_get_methods_to(field.type)
         instances[field.name] = instance
 
     make_singleton(config_class)
@@ -96,7 +94,7 @@ def _create_config_class_instance(
     instance = config_class(**instances)
     setattr(instance, "_sections", sections)
 
-    add_contains_getattribute_getitem_get_methods_to(config_class, sections)
+    add_contains_getattribute_getitem_get_methods_to(config_class)
     freeze_class(instance)
 
     return instance
