@@ -1,8 +1,9 @@
 """Contains helper functions to modify classes that overwrite specific methods."""
 import dataclasses
-from typing import Type, Any
+from typing import Any, Type
 
 from autoconfiguration.exceptions.config_class_errors import ConfigClassAttributeError
+from autoconfiguration.helpers import instances
 
 
 class _MissingValue:
@@ -12,12 +13,6 @@ class _MissingValue:
 MISSING_VALUE = _MissingValue()
 
 
-class Constants:
-    """Used to save the instance of the config class."""
-
-    config_instance = None
-
-
 def make_singleton(obj: Type[Any]) -> None:
     """
     Modifies the passed type to ensure that only one instance of the type can be
@@ -28,9 +23,9 @@ def make_singleton(obj: Type[Any]) -> None:
 
     def __new__(cls: Type[Any], *args: Any, **kwargs: Any) -> Any:
         # pylint: disable=unused-argument
-        if not hasattr(Constants, "config_instance") or not Constants.config_instance:
-            Constants.config_instance = object.__new__(cls)
-        return Constants.config_instance
+        if not instances.has(cls):
+            instances.append(object.__new__(cls))
+        return instances.get_by(cls)
 
     setattr(obj, "__new__", __new__)
 
